import React from 'react'
import { Input, InputNumber, DatePicker } from 'antd'
import locale from 'antd/lib/date-picker/locale/zh_CN'
import moment from 'moment'

const ValueEdit = (props) => {

  const {
    onChange,
    value,
    disabled,
    placeholder,
    widget,
    format,
    min,
    max,
    formatter,
  } = props

  if (widget === 'DateTime') {
    const isValid = value ? moment(value)._isValid : false
    const timeOtions = format === 'dateTime' ?
      {
        showTime: {
          minuteStep: 5,
          format: 'HH:mm'
        },
        format: 'YYYY-MM-DD HH:mm'
      }
      :
      {
        picker: format,
        showTime: false
      }
    return (
      <DatePicker
        disabled={disabled}
        placeholder={disabled ? (placeholder || '') : (placeholder || '点击选择日期')}
        value={isValid ? moment(value) : null}
        showNow
        {...timeOtions}
        style={{ width: '100%' }}
        locale={locale}
        onChange={(date) => {
          if (date && date._d) {
            onChange(moment(date._d).format('YYYY-MM-DD HH:mm:ss'))
          } else {
            onChange('')
          }
        }}
      />
    )
  }

  if (widget === 'NumberInput') {
    return (
      <InputNumber
        min={min || Number.MIN_SAFE_INTEGER}
        max={max || Number.MAX_SAFE_INTEGER}
        step={(formatter === '${百分比}' && isStoreFormatter) ? 0.01 : 1}
        placeholder={disabled ? (placeholder || '') : (placeholder || '请输入内容')}
        disabled={disabled}
        value={value === '' ? null : Number(value)}
        onChange={(value) => {
          if (value !== null) {
            onChange(`${value}`)
          } else {
            onChange('')
          }
        }}
        style={{ width: '100%' }}
      />
    )
  }

  return (
    <Input
      disabled={disabled}
      onChange={(e) => onChange(e.target.value)}
      value={value}
    />
  )

}

export default ValueEdit